Linh
====


0.0
---
1. Create the Lexer
```
linh = Linh('div')
linh.render() # <div>
```


0.1
---

1. div to <div>
2. #id to <div id="id">




TODO
----

* variables
* filter
* django tags
* django tags inline (e.g.: img src="{% static 'image.png' %}'
* doctype

